PyXMake Developer Guide: PyXMake.API Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Classes
PyXMake.API Namespace Reference

Contains all classes and functions to create a web application. More...

## Classes
class | Backend
| Class instance to define PyXMake's web API instance. More...
class | Base
| Abstract base class for all API objects. More...
class | Frontend
| Class instance to define PyXMake's web API instance. More...

## Detailed Description

Contains all classes and functions to create a web application.

    Contains all classes and functions to define a web interface

    @note: PyXMake module
    Created on 19.11.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  19.11.2020

Notes/Changes
  - Added documentation // mg 19.11.2020